---
name: Bug Report
about: Bug Report
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
<!--
A clear and concise description of what the bug is.
-->

**To Reproduce**
<!--
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error
-->

**Expected behavior**
<!--
A clear and concise description of what you expected to happen.
-->

**Environment**
 - OS:
 - Python:
 - Package Manager [e.g. `pip`, `conda`]: 

**Additional Context**
<!--
Add any other context about the problem here.
-->
